# Procrustean SVD (proSVD)
Tools for streaming dimension reduction analyses of neural data.

![alt text](lock-in.gif)

See `demos/` for usage.

#### To build:
```
$ git clone https://github.com/pearsonlab/proSVD
$ cd proSVD
$ pip install .
```

#### To import:
```
from proSVD import proSVD
```

Under active development! Please contact pranjal.gupta@duke.edu for any inquiries. 
